{% load crispy_forms_tags %}
<label>Title</label>
{{ form.name|as_crispy_field }}
<label>Description</label>
{{ form.description|as_crispy_field }}
<label>Location</label>
{{ form.location|as_crispy_field }}
<div class="row">
    <div class="col-6">
        <label>Start</label>
        {{ form.start_time|as_crispy_field }}
    </div>
    <div class="col-6">
        <label>Ends</label>
        {{ form.end_time|as_crispy_field }}
    </div>
</div>
<label>Cover</label>
<div class="custom-file">
    {{ form.cover|as_crispy_field }}
</div>
<div class="d-flex justify-content-end my-3">
    <input type="hidden" name="parent" value="{{event.id}}">
    <input type="hidden" name="form-id" value="eventupdate">
    <button type="submit" class="btn btn-shappire submit-btn">Update</button>
</div>