{% load i18n %}
<p class="text-center text-dark">{% trans "We have deleted the requested record" %}.</p>   
<div class="d-flex justify-content-center">
    <button onclick="refresh()" class="btn btn-success z-max">{% trans "Continue" %}</button>
</div>

